
#ifndef KALARMCAL_EXPORT_H
#define KALARMCAL_EXPORT_H

#ifdef KALARMCAL_STATIC_DEFINE
#  define KALARMCAL_EXPORT
#  define KALARMCAL_NO_EXPORT
#else
#  ifndef KALARMCAL_EXPORT
#    ifdef kalarmcal_EXPORTS
        /* We are building this library */
#      define KALARMCAL_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KALARMCAL_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KALARMCAL_NO_EXPORT
#    define KALARMCAL_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KALARMCAL_DEPRECATED
#  define KALARMCAL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KALARMCAL_DEPRECATED_EXPORT
#  define KALARMCAL_DEPRECATED_EXPORT KALARMCAL_EXPORT KALARMCAL_DEPRECATED
#endif

#ifndef KALARMCAL_DEPRECATED_NO_EXPORT
#  define KALARMCAL_DEPRECATED_NO_EXPORT KALARMCAL_NO_EXPORT KALARMCAL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KALARMCAL_NO_DEPRECATED
#    define KALARMCAL_NO_DEPRECATED
#  endif
#endif

#endif /* KALARMCAL_EXPORT_H */

// This library was built to use Akonadi.
// It must be rebuilt in order to use KResources.
#ifdef KALARMCAL_USE_KRESOURCES
#undef KALARMCAL_USE_KRESOURCES
#endif
